<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Helper pomagający w nawiązaniu sesji umożliwiającej autentykację w portalu ePUAP przy pomocy protokołu SAML 2.0
 * 
 * @author Extern
 * Metody wymagają ustawienia następujacych wartoci w pliku konfiguracji aplikacji
 * 
 * $config['urlSecurityServer'] = 'https://hetmantest.epuap.gov.pl/DracoEngine2/draco.jsf';  //adres url serwera bezpieczeństwa Draco
 * $config['urlSPServer'] = 'http://url_do_naszej_stony_odbierajacej_SAMLart_i_wysylajacej_ArtifactResolve_w_celu_pobrania_TGSID';		//adres url	SP czyli skryptu który u nas rozumie odpowiedz SAMLart
 * $config['appID'] = '';											//identyfikator aplikacji w konsoli Draco
 * 
 * Rozwiazywanie artefaktu
 * $config['urlEngineSAMLArtifact'] = 'https://hetmantest.epuap.gov.pl/axis2/services/EngineSAMLArtifact';  //adres uslugi do odbierania zapytania typu ArtifactResolve wysyłanego protokolem SOAP
 *
 * COAP HTTP proxy, jeli nie będą te zmienne ustawione lub będą miały wartoć pustych stringów parametry proxy nie zostaną wpisane do ustawień clienta SOAP (w przypadku bezporedniego połączenia tak należy to skonfigurować)
 * $config['proxyServer'] = '';					//adres serwera proxy w organizacji
 * $config['proxyPort'] = 8080;								//port serwera proxy
 * $config['proxyUser'] = '';						//użytkownik
 * $config['proxyPassword'] = '';					//hasło

 */
if ( ! function_exists('getUniqueID'))
{
	/**
	 * 
	 * Generacja unikalnego identyfikatora umieszczanego jako atrybut ID w zapytaniach typu AuthnRequest i ArtifactResolve
	 * @param number $length rzeczywista liczba oznaczająca długoć wygenerowanego identyfikatora
	 * @return unikalny identyfikator
	 */
    function getUniqueID($length) {
      $chars = "abcdef0123456789";
      $chars_len = strlen($chars);
      $uniqueID = "";
      for ($i = 0; $i < $length; $i++)
        $uniqueID .= substr($chars,rand(0,15),1);
      return "_".$uniqueID;
    }
}
if ( ! function_exists('getTimestamp'))
{
	/**
	 * 
	 * Funkcja do generacji znacznika czasu wykorzystywanego w zapytaniach np. jako atrybut IssueInstant
	 * @param integer $interval wielkoć przesunięcia w sekundach jaka zostanie dodana do czasu aktualnego (może być ujemna)
	 * @return sformatowany w formacie TimeStamp znacznik czasu
	 */
    function getTimestamp($interval=0) {
      date_default_timezone_set('Europe/Warsaw');
      return strftime("%Y-%m-%dT%H:%M:%SZ",mktime()+$interval);
	  }
}
if ( ! function_exists('getSAMLRequestUrl'))
{
	/**
	 * 
	 * Metoda tworząca zapytanie typu AuthnRequest (o autoryzację) oraz zwracajaca pełny url z zakodowanym właniwie parametrem "SAMLRequest"
	 * Metoda wymaga ustawienia właciwych parametrów konfiguracyjnych w pliku konfiguracji aplikacji
	 * @author Extern
	 * @return URL do serwera bezpieczeństwa z wypełnionym parametrem SAMLRequest
	 * @uses $this->load->helper('saml'); 
	 * @uses header('Location: '.getSAMLRequestUrl());
	 */
	function getSAMLRequestUrl()
	{
			$CI =& get_instance();
			$SAMLRequest="<samlp:AuthnRequest xmlns:samlp=\"urn:oasis:names:tc:SAML:2.0:protocol\" ID=\"".getUniqueID(20)."\" Version=\"2.0\" "
			."IssueInstant=\"".getTimestamp()."\" "
			."Destination=\"".$CI->config->item('urlSecurityServer')."\" "
			."IsPassive=\"false\" "
			."AssertionConsumerServiceURL=\"".$CI->config->item('urlSPServer')."\">"
			."<saml:Issuer xmlns:saml=\"urn:oasis:names:tc:SAML:2.0:assertion\">".$CI->config->item('appID')."</saml:Issuer>
			</samlp:AuthnRequest>";
	
			return $CI->config->item('urlSecurityServer').'?SAMLRequest='.addslashes(rawurlencode(base64_encode(gzdeflate($SAMLRequest))));		
	}
}
if ( ! function_exists('getTGSID'))
{
	/**
	 * 
	 * Metoda do wysyłania do serwera (protokołem SAML) zapytania typu "ArtifactResolve" czyli pytania o asercję czyli w przypadku ePUAPu o identyfikator TGSID
	 * Dodatkowo metoda ustawia "cookie" o nazwie TGSID zawierające pobrany identyfikator sesji (jeli się udało pobrać)
	 * Metoda wymaga obecnoci w katalogu "libraries" biblioteki "nusoap".
	 *   
	 * @author Extern
	 * @param string $SAMLart referencja do artefaktu uzyskana jako parametr SAMLart po wysłaniu zapytania typu "AuthnRequest"
	 * @param ref strign $msg referencja do zmiennej typu string z przeznaczeniem na komunikaty błędu wygenerowane w czasie trwania metody (metoda nie rzuca wyjątków)
	 * @return Zwraca obiekt typu Array zawierający właciwoci "TGSID" jako string i "expire" jako timestamp czasu ważnoci ciasteczka, "userID" czyli login usera. w przypadku niepowodzenia zamiast obiektu zwraca FALSE w. Jeli metoda się nie powiedzie w zmiennej $msg powinien znaleć się komunikat błędu.
	 * @uses if(isset($_GET['SAMLart']))
     * @uses {
     * @uses 	$this->load->model('admin');
     * @uses 	$msg = '';
     * @uses	$TGSID = getTGSID($_GET["SAMLart"],$msg);
     * @uses }
 
	 */
	function getTGSID($SAMLart,&$msg)
	{
		$CI =& get_instance();
		$CI->load->library('nusoap');
		
		$artifactResolve="<samlp:ArtifactResolve ID=\"".getUniqueID(20)."\" "
		."IssueInstant=\"".getTimestamp()."\" Version=\"2.0\" "
		."xmlns:samlp=\"urn:oasis:names:tc:SAML:2.0:protocol\">"
		."<saml:Issuer xmlns:saml=\"urn:oasis:names:tc:SAML:2.0:assertion\">".$CI->config->item('appID')."</saml:Issuer>"
		."<samlp:Artifact>".$SAMLart."</samlp:Artifact>"
		."</samlp:ArtifactResolve>";
		$client=new nusoap_client($CI->config->item('urlEngineSAMLArtifact'));
		$client->soap_defencoding = 'UTF-8';
		$client->decode_utf8 = true;
		$client->http_encoding = 'UTF-8';
		$client->xml_encoding = 'UTF-8';
		if($CI->config->item('proxyServer') && $CI->config->item('proxyServer') != '' && $CI->config->item('proxyUser') && $CI->config->item('proxyUser') != '' && $CI->config->item('proxyPassword') && $CI->config->item('proxyPassword') != '')
		{
			$proxyPort = 8080;
			if($CI->config->item('proxyPort') && $CI->config->item('proxyPort') != '')
				 $proxyPort = $CI->config->item('proxyPort');
			$client->setHTTPProxy($CI->config->item('proxyServer'),$proxyPort,$CI->config->item('proxyUser'),$CI->config->item('proxyPassword'));
		}
		$client->setCurlOption(CURLOPT_SSLVERSION, 3); //z nieznanych mi przyczyn w pewnym momecie php zaczelo nagle ustawiać błędną wersję ssla co powodowało błędy w dogadywaniu się CURLa i serwera więc trzeba to ustawić ręcznie
		$result = $client->call('artifactResolve', $artifactResolve,'http://tempuri.org',"artifactResolve",false,null,'document');
		if($client->fault)
		{
			$msg = $client->fault;
			return false;
		}
		else
		{
			if ($client->getError())
            {			
                $msg = $client->getError();
				return false;
            }
            else
            {
				if(isset($result))
				{
					if($result['Response']['Status']['StatusCode']['!Value'] =='urn:oasis:names:tc:SAML:2.0:status:Success')
					{
						//setcookie("TGSID", substr($result['Response']['Assertion']['!ID'],1,strlen($result['Response']['Assertion']['!ID'])), strtotime($result['Response']['Assertion']['Subject']['SubjectConfirmation']['SubjectConfirmationData']['!NotOnOrAfter']),'/');
						return array("TGSID"=>substr($result['Response']['Assertion']['!ID'],1,strlen($result['Response']['Assertion']['!ID'])),
													"expire"=>strtotime($result['Response']['Assertion']['Subject']['SubjectConfirmation']['SubjectConfirmationData']['!NotOnOrAfter']),
													"nameID"=>$result['Response']['Assertion']['Subject']['NameID']['!']
									);  
					}
					else
					{
						$msg = "zapytanie nie zakończylo sie sukcesem";
						return false;
					}
				}
			}
		}
		unset($client);				
	}
}
if ( ! function_exists('getLogoutURL'))
{	
	function getLogoutURL()
	{
		$CI =& get_instance();
		return $CI->config->item('urlSecurityServer').'?ORIGIN='.bin2hex(str_replace('&amp;', '&', $CI->config->item('urlSPServer'))).'&APPID='.$CI->config->item('appID').'&LOGOUT=Y';
	}
}
if ( ! function_exists('getRegisterURL'))
{	
	function getRegisterURL()
	{
		$CI =& get_instance();
		return $CI->config->item('urlRegister');
	}
}

if ( ! function_exists('callSecRequest'))
{	
	function callSecRequest($serviceUrl,$serviceMethod,$requestContent,&$msg,$style='document',$use='literal')
	{
		$CI =& get_instance();
		//$CI->load->library('xmlseclibs');
		$CI->load->library('nusoap');
		require_once(APPPATH.'libraries/xmlseclibs.php');
		$client=new nusoap_client($serviceUrl);
		$client->soap_defencoding = 'UTF-8';
		$client->decode_utf8 = true;
		$client->http_encoding = 'UTF-8';
		$client->xml_encoding = 'UTF-8';
		if($CI->config->item('proxyServer') && $CI->config->item('proxyServer') != '' && $CI->config->item('proxyUser') && $CI->config->item('proxyUser') != '' && $CI->config->item('proxyPassword') && $CI->config->item('proxyPassword') != '')
		{
			$proxyPort = 8080;
			if($CI->config->item('proxyPort') && $CI->config->item('proxyPort') != '')
				 $proxyPort = $CI->config->item('proxyPort');
			$client->setHTTPProxy($CI->config->item('proxyServer'),$proxyPort,$CI->config->item('proxyUser'),$CI->config->item('proxyPassword'));
		}
		$client->setCurlOption(CURLOPT_SSLVERSION, 3);
		$securityStart="<wsse:Security \n"
						."xmlns:wsse=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd\"\n"
						."xmlns:wsu=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd\"\n"
						."SOAP-ENV:mustUnderstand=\"1\">\n";
		$securityEnd="</wsse:Security>\n";
		$BinarySecurityToken="<wsse:BinarySecurityToken \n"
							."wsu:Id=\"binarytoken\" \n"
							."ValueType=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-x509-token-profile-1.0#X509v3\" \n"
							."EncodingType=\"http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-soap-message-security-1.0#Base64Binary\">\n"
							.implode("\n",array_slice(explode("\n",$CI->config->item('pubKey')),1,-1))  //a tu wycinamy napisy BEGIN CERTYFICATE i END CERTYFICATE ponieważ EPUAP oczekuje BinarySecurityToken jako base64 bez tych nagłówków
							."</wsse:BinarySecurityToken>\n";	
		$timestamp = 	"<wsu:Timestamp>"
						."<wsu:Created>".getTimestamp()."</wsu:Created>"
						."<wsu:Expires>".getTimestamp(60*60)."</wsu:Expires>"  //przesuniecie o godzinę
						."</wsu:Timestamp>";	
						
		$sheaders = $securityStart.$BinarySecurityToken.$timestamp.$securityEnd; //komponujemy dodatek "security" który zostanie umieszczony w nagłówku SOAP:Header
		
		$soapEnvelope = $client->serializeEnvelope($requestContent, $sheaders, array(), $style, $use);  //tworzymy całą kopertę SOAP z zawartym tam nagłówkiem (jeszcze nie podpisanym i nie są przydzielone również referencje
		//w tym momecie mamy już wstępnie utworzoną kopertę SOAP z zawartocią SOAP:BODY jednak nie jest jeszcze w pełni utworzony nagłówek security ani nie jest tam wstawiony podpis które będzie wstawiony tam w elemencie "signature" brakuje również referecji wskazujących które elementy koperty SOAp są podpisane
		//dlatego teraz zajmiemy się dalszym wstawianiem odpowiednich danych do elementu security.
		$doc = new DOMDocument();
		$doc->loadXML($soapEnvelope); //całą kopertę soap wczytujemy do drzewa dom i na tym drzewie będziemy już rzebić
		//znajdujemy element body aby dodac do niego referencje poniewaz tylko body bedziemy podpisywali
		$xp = new DOMXPath($doc);
		$wsseNamespace = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd';
		$wsuNamespace = 'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd';
		//musimy zarejestrować właciwe namespaces z prefixami aby zapytania xpath umiały znaleć właciwe węzły 
		$xp->registerNamespace('SOAP-ENV', 'http://schemas.xmlsoap.org/soap/envelope/'); //namespace sekcji body
		$xp->registerNamespace('wsse',$wsseNamespace); //namespace node security
		$xp->registerNamespace('wsu',$wsuNamespace);
		$xp->registerNamespace('ds',XMLSecurityDSig::XMLDSIGNS);

		$bodyNode = $xp->query('//SOAP-ENV:Body')->item(0);
		if($bodyNode)									//znalelimy element soap:body mozemy przypisać mu id i dodać do niego referencje w elemencie "Signature"->"SignedInfo"->"Reference[URI]" 
		{
			//echo "jest BODY";
			$objDSig = new XMLSecurityDSig();			//tworzymy obiekt za pomocą którego będziemy podpisywali kopertę SOAP
			$objDSig->setCanonicalMethod(XMLSecurityDSig::EXC_C14N);
			$objDSig->addReference($bodyNode, XMLSecurityDSig::SHA1,NULL,array('prefix'=>'wsu','prefix_ns'=>$wsuNamespace));  //dodajemy referencje do body możemy tu użyć gotowej funkcji z biblioteki "xmlseclibs"

			//teraz dodamy referencję do elementu Timestamp opisującego moment czasowy podpisu
			$timestampNode = $xp->query('//wsu:Timestamp')->item(0);
			if($timestampNode)
				$objDSig->addReference($timestampNode, XMLSecurityDSig::SHA1,NULL,array('prefix'=>'wsu','prefix_ns'=>$wsuNamespace));
			$objKey = new XMLSecurityKey(XMLSecurityKey::RSA_SHA1, array('type'=>'private'));
			$objKey->loadKey($CI->config->item('privKey'));   //tworzymy obiekt klucza prywatnego, w tym wypadku odczytujemy go z konfiguracji
			$objDSig->sign($objKey);							//podpisujemy kopertę SOAP kluczem prywatnym
			//$objDSig->add509Cert($pub_key);\				
			//znajdujemy element do którego wstawimy sekcję podpisu w tym wypadku jest to Security
			$securityNode = $xp->query('//wsse:Security')->item(0);							
			if($securityNode)
			{
				//echo "jest Security node";
				//teraz musimy dodać włanie wygenerowany podpis (na podstawie referecji do zewnętrzego obiektu) do całoći koperty SOAP
				$timestampNode = $xp->query('//wsu:Timestamp')->item(0);
				if($timestampNode)
					$objDSig->insertSignature($securityNode,$timestampNode);  //wstawiamy podpis do węzła "Security" ale ma być umieszczony przed węzłem "TimeStamp" (to ważne aby był przed nim)
					//$objDSig->appendSignature($securityNode);
					//Teraz ustawimy referencje do BinarySecurityToken niestety ponieważ funkcja addRefInternal jest prywatna nie możemy jej stąd wywołać i musimy dodanie atrybutu reference zrobić na piechotę
				$binarySecurityTokenNode = $xp->query('//wsse:BinarySecurityToken')->item(0);
				if($binarySecurityTokenNode)
				{
					$uri = XMLSecurityDSig::generate_GUID();
					//echo "jest BinarySecurityToken";
					$binarySecurityTokenNode->setAttributeNS($wsuNamespace,'Id', $uri); //dodajemy atrybut Id do BinarySecurityToken aby potem użyć tego samego identyfikatora przy dodawaniu referencji w elemencie securityTokenReference
					$keyInfoNode = $xp->query('//ds:KeyInfo')->item(0);
					if(!$keyInfoNode)
					{
						$signatureNode = $xp->query('//ds:Signature')->item(0);	
						$keyInfoNode = $doc->createElementNS(XMLSecurityDSig::XMLDSIGNS,'ds:KeyInfo');
						if($signatureNode)
							$signatureNode->appendChild($keyInfoNode);
					}
					$securityTokenReferenceNode = $xp->query('//wsse:SecurityTokenReference')->item(0);
					if($keyInfoNode && ! $securityTokenReferenceNode)
					{
						$securityTokenReferenceNode = $doc->createElementNS($wsseNamespace, 'wsse:SecurityTokenReference');
						$referenceNode = $doc->createElementNS($wsseNamespace,'wsse:Reference');
						$referenceNode->setAttribute("URI", '#'.$uri);         //dodajemy teraz do referencji ten sam identyfikator co jest w BinarySecurityToken z elementu Security który właciwie to nie wchodzi do podpisu
						$securityTokenReferenceNode->appendChild($referenceNode);
						$keyInfoNode->appendChild($securityTokenReferenceNode);
						//$objDSig->addRefInternal($securityTokenReferenceNode,$binarySecurityTokenNode, XMLSecurityDSig::SHA1);
					}
				}
				$soapEnvelope = $doc->saveXML();
			}//if($securityNode)
			else
			{
				$msg .="Nie odnaleziono elementu wsse:Security";	
			}
		}//if($bodyNode)
		else
		{
			$msg .="Nie odnaleziono elementu SOAP-ENV:Body";
		}				
		$client->operation = $serviceMethod;    //ustawiamy metodę która ma być wywołana w nagłówku HTTP SOAPAction
		//echo $soapEnvelope;	
		$result2  = $client->send($soapEnvelope, $serviceMethod);   //wysyłamy kopertę SOAP
		if($client->fault)
		{
			$msg .= "ERROR przy wysyłaniu metody ".$serviceMethod." :".$client->fault." ".var_export($result2,true);
			//echo  'Error: '.$client->fault;
			//print_r($result2);	
			//echo '<h2>Request</h2>';
			//echo '<pre>' . htmlspecialchars($client->request, ENT_QUOTES) . '</pre>';
			//echo '<h2>Response</h2>';
			//echo '<pre>' . htmlspecialchars($client->response, ENT_QUOTES) . '</pre>';
			// Display the debug messages
			//echo '<h2>Debug</h2>';
			//echo '<pre>' . htmlspecialchars($client->debug_str, ENT_QUOTES) . '</pre>';		
		}
		else
		{
			if ($client->getError())
			{		
				$msg .= "ERROR przy wysyłaniu metody ".$serviceMethod." :".$client->getError()." ".var_export($result2,true);	
				//echo 'Error2: '.$client->getError();
				//print_r($result2);
				//echo '<pre>' . htmlspecialchars($client->request, ENT_QUOTES) . '</pre>';
			}
			else   //udało się więc zwracamy wynik jaki dostalimy od klienta
			{				
				//echo '<h2>Result</h2><pre>';
				//print_r($result2);				
				//echo '</pre>';
				//echo '<h2>Request</h2><pre>';
				//echo '<pre>' . htmlspecialchars($client->request, ENT_QUOTES) . '</pre>';
				//echo '<h2>Response</h2><pre>';
				//echo '<pre>' . htmlspecialchars($client->response, ENT_QUOTES) . '</pre>';
				//print_r($result2);
				if(isset($result2['faultcode']))
				{
					$msg .=  'faultcode='.$result2['faultcode'].' faultstring='.$result2['faultstring'].' detail='.$result2['detail'];
					return false;
				}
				return $result2;				
			}
		}
		return false;						
	}//callSecRequest
}
if ( ! function_exists('getDecisionQuery'))
{	
	/**
	 * 
	 * zwraca informację o tym czy dane uprawnienie jest dozwolone czy zabronione
	 * @param string $rightName nazwa uprawnienia na ePuap
	 * @param unknown_type $msg zmienna na komunikat błędu
	 * @return false lub true
	 */
	function getDecisionQuery($rightName,&$msg)
	{		
		$CI =& get_instance();
		$authzDecisionQuery="<samlp:AuthzDecisionQuery ID=\"".getUniqueID(20)."\" "
							."IssueInstant=\"".getTimestamp()."\" "
							."Resource=\"".$CI->config->item('appID')."\" Version=\"2.0\" "
							."xmlns:samlp=\"urn:oasis:names:tc:SAML:2.0:protocol\">"
							."<saml:Subject xmlns:saml=\"urn:oasis:names:tc:SAML:2.0:assertion\">"
							."<saml:NameID>".$_COOKIE['nameID']."</saml:NameID>"
							."</saml:Subject>"
							."<saml:Action Namespace=\"hetman.epuap.gov.pl\" "
							."xmlns:saml=\"urn:oasis:names:tc:SAML:2.0:assertion\">".$rightName."</saml:Action>"
							."<saml:Evidence xmlns:saml=\"urn:oasis:names:tc:SAML:2.0:assertion\">"
							."<saml:AssertionIDRef>"./*substr($_COOKIE['TGSID'],1,strlen($_COOKIE['TGSID']))*/"_".$_COOKIE['TGSID']."</saml:AssertionIDRef>"
							."</saml:Evidence>"
							."</samlp:AuthzDecisionQuery>";
		
		$respond = callSecRequest($CI->config->item('urlEngineSAMLDecision'),'decisionQuery',$authzDecisionQuery,$msg);
		if($respond)
			return  $respond['Assertion']['AuthzDecisionStatement']['!Decision'] == 'Permit';
		return false;		
	}
}
if ( ! function_exists('getUserInfo'))
{	
	/**
	 * 
	 * medota zwraca dane o użytkowniku
	 * @param string $urlAuthorizationWS adres url usługi
	 * @param string $appID identyfikator aplikacji w ePUAP
	 * @param unknown_type $msg zmienna na komunikat błędu
	 * @author Extern
	 * @return string ze strukturą xml zawierajacą dane użytkownika lub false w przypadku porażki
	 */
	function getUserInfo(&$msg)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();			
			$getUserInfoRequest = "<ns:getUserInfo xmlns:ns=\"http://ejb.draco.comarch.com\">"
							."<ns:tgsId>".$_COOKIE['TGSID']."</ns:tgsId>"
							."<ns:appId>".$CI->config->item('appID')."</ns:appId>"
							."</ns:getUserInfo>";							
			$respond = callSecRequest($CI->config->item('urlAuthorizationWS'),'getUserInfo',$getUserInfoRequest,$msg);			
			return $respond;							
		}
		return false;		
	}
}
if ( ! function_exists('getPermissionInfo'))
{	
	function getPermissionInfo(&$msg)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();			
			$getPermissionInfoRequest = "<ns:getPermissionInfo xmlns:ns=\"http://ejb.draco.comarch.com\">"
							."<ns:tgsId>".$_COOKIE['TGSID']."</ns:tgsId>"
							."<ns:appId>".$CI->config->item('appID')."</ns:appId>"
							."</ns:getPermissionInfo>";
							
			$respond = callSecRequest($CI->config->item('urlAuthorizationWS'),'getPermissionInfo',$getPermissionInfoRequest,$msg);
			return $respond;							
		}
		return false;		
	}
}
if ( ! function_exists('dajPodmiot'))
{	
	function dajPodmiot($organizationID,&$msg)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();			
			$dajPodmiotRequest = "<dajPodmiot xmlns=\"http://podmioty.ub_ws\">"
							."<organizationID>".$organizationID."</organizationID>"
							."</dajPodmiot>";
			$respond = callSecRequest($CI->config->item('urlPodmioty'),'dajPodmiot',$dajPodmiotRequest,$msg);
			return $respond;							
		}
		return false;		
	}
}

if ( ! function_exists('getContext'))
{	
	function getContext(&$msg)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();			
			$getContextRequest = "<ns:getContext xmlns:ns=\"http://ejb.draco.comarch.com\">"
							."<ns:tgsId>".$_COOKIE['TGSID']."</ns:tgsId>"
							."<ns:appId>".$CI->config->item('appID')."</ns:appId>"
							."</ns:getContext>";							
			$respond = callSecRequest($CI->config->item('urlAuthorizationWS'),'getContext',$getContextRequest,$msg);
			return $respond;							
		}
		return false;		
	}
}

if ( ! function_exists('getRoleAttributesInfo'))
{	
	function getRoleAttributesInfo(&$msg)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();			
			$getRoleAttributesInfoRequest = "<ns:getRoleAttributesInfo xmlns:ns=\"http://ejb.draco.comarch.com\">"
							."<ns:tgsId>".$_COOKIE['TGSID']."</ns:tgsId>"
							."<ns:appId>".$CI->config->item('appID')."</ns:appId>"
							."</ns:getRoleAttributesInfo>";							
			$respond = callSecRequest($CI->config->item('urlAuthorizationWS'),'getRoleAttributesInfo',$getRoleAttributesInfoRequest,$msg);
			return $respond;							
		}
		return false;		
	}
}
//hasTrustedProfilePerson(java.lang.String tgsid)
if ( ! function_exists('hasTrustedProfilePerson'))
{
	/**
 * funkcja sprawdzająca czy użytkownik z zalogowanej aktualnie sesji ma w ePuap profil zaufany.
 */
	function hasTrustedProfilePerson(&$msg)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();			
			$hasTrustedProfilePersonRequest = "<ns:hasTrustedProfilePerson xmlns:ns = \"http://signing.ws.comarch.gov\">"
											."<ns:tgsid>".$_COOKIE['TGSID']."</ns:tgsid>"
											."</ns:hasTrustedProfilePerson>";							
			$respond = callSecRequest($CI->config->item('urlPZ'),'hasTrustedProfilePerson',$hasTrustedProfilePersonRequest,$msg,'rpc','literal');
			return $respond;										
		}
		return false;
	}
}

if ( ! function_exists('addDocumentToSigning'))
{
	/**
 * funkcja do podpisywania dokumentów profilem zaufanym z ePUAP
 */
	function addDocumentToSigning(&$msg,$doc,$successURL,$failureURL,$additionalInfo='')
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();
			$addDocumentToSigningRequest = "<ns:addDocumentToSigning xmlns:ns = \"http://signing.ws.comarch.gov\">"
											."<ns:doc>".base64_encode($doc)."</ns:doc>"
											."<ns:successURL>".$successURL."</ns:successURL>"
											."<ns:failureURL>".$failureURL."</ns:failureURL>"
											."<ns:additionalInfo>".$additionalInfo."</ns:additionalInfo>"
											."</ns:addDocumentToSigning>";											
			$respond = callSecRequest($CI->config->item('urlPZ'),'addDocumentToSigning',$addDocumentToSigningRequest,$msg,'rpc','literal');
			return $respond;							
			
		}
		return false;
	}
}

if ( ! function_exists('getSignedDocument'))
{
	/**
 * funkcja do pobierania dokumentu podpisanego profilem zaufanym
 */
	function getSignedDocument(&$msg,$id)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();
			$getSignedDocumentRequest = "<ns:getSignedDocument xmlns:ns = \"http://signing.ws.comarch.gov\">"
											."<ns:id>".$id."</ns:id>"
											."</ns:getSignedDocument>";											
			$respond = callSecRequest($CI->config->item('urlPZ'),'getSignedDocument',$getSignedDocumentRequest,$msg,'rpc','literal');
			return $respond;										
		}
		return false;
	}
}

if ( ! function_exists('verifySignedDocument'))
{
	/**
 * funkcja do weryfikowania dokumentu podpisanego profilem zaufanym
 */
	function verifySignedDocument(&$msg,$doc)
	{
		if(isset($_COOKIE['TGSID']))
		{
			$CI =& get_instance();
			$verifySignedDocumentRequest = "<ns:verifySignedDocument xmlns:ns = \"http://signing.ws.comarch.gov\">"
											."<ns:document>".base64_encode($doc)."</ns:document>"
											."</ns:verifySignedDocument>";											
			$respond = callSecRequest($CI->config->item('urlPZ'),'verifySignedDocument',$verifySignedDocumentRequest,$msg,'rpc','literal');
			return $respond;										
		}
		return false;
	}
}

/* End of file epuap_helper.php */
/* Location: ./system/helpers/epuap_helper.php */